%bcond_with bootstrap
# temporalily ignore test failures
%ifarch %{ix86} aarch64 x86_64
%bcond_without ignore_tests
%else
%bcond_with ignore_tests
%endif

# build ids are not currently generated:
# https://code.google.com/p/go/issues/detail?id=5238
#
# also, debuginfo extraction currently fails with
# "Failed to write file: invalid section alignment"
%global debug_package %{nil}

# we are shipping the full contents of src in the data subpackage, which
# contains binary-like things (ELF data for tests, etc)
%global _binaries_in_noarch_packages_terminate_build 0

# Do not check any files in doc or src for requires
%global __requires_exclude_from ^(%{_datadir}|/usr/lib)/%{name}/(doc|src)/.*$

# Don't alter timestamps of especially the .a files (or else go will rebuild later)
# Actually, don't strip at all since we are not even building debug packages and this corrupts the dwarf testdata
%global __strip /bin/true

# rpmbuild magic to keep from having meta dependency on libc.so.6
%define _use_internal_dependency_generator 0
%define __find_requires %{nil}
%global __spec_install_post /usr/lib/rpm/check-rpaths   /usr/lib/rpm/check-buildroot  \
  /usr/lib/rpm/brp-compress

%global golibdir %{_libdir}/golang

# Golang build options.

# Build golang using external/internal(close to cgo disabled) linking.
%ifarch %{ix86} x86_64 ppc64le %{arm} aarch64 s390x
%global external_linker 1
%else
%global external_linker 0
%endif

# Build golang with cgo enabled/disabled(later equals more or less to internal linking).
%ifarch %{ix86} x86_64 ppc64le %{arm} aarch64 s390x
%global cgo_enabled 1
%else
%global cgo_enabled 0
%endif

# Use golang/gcc-go as bootstrap compiler
%if %{with bootstrap}
%global golang_bootstrap 0
%else
%global golang_bootstrap 1
%endif

# Controls what ever we fail on failed tests
%if %{with ignore_tests}
%global fail_on_tests 0
%else
%global fail_on_tests 1
%endif

# Build golang shared objects for stdlib
%ifarch %{ix86} x86_64 ppc64le %{arm} aarch64
%global shared 1
%else
%global shared 0
%endif

# Pre build std lib with -race enabled
%ifarch x86_64
%global race 1
%else
%global race 0
%endif

%if 0%{?rhel} > 5 || 0%{?fedora} < 21
%global gopath          %{_datadir}/gocode
%global golang_arches       %{ix86} x86_64 %{arm} ppc64le aarch64
%endif

# Fedora GOROOT
%global goroot          /usr/lib/%{name}

%ifarch x86_64
%global gohostarch  amd64
%endif
%ifarch %{ix86}
%global gohostarch  386
%endif
%ifarch %{arm}
%global gohostarch  arm
%endif
%ifarch aarch64
%global gohostarch  arm64
%endif
%ifarch ppc64
%global gohostarch  ppc64
%endif
%ifarch ppc64le
%global gohostarch  ppc64le
%endif
%ifarch s390x
%global gohostarch  s390x
%endif

%global go_api 1.15
%global go_version 1.15
%global go_commit c79c5e1aa427eceb585f839a81d02c5390457a9c
%global go_shortcommit %(c=%{go_commit}; echo ${c:0:7})

Name:           golang
Version:        %go_version
Release:        0.14git%{go_shortcommit}%{?dist}
Summary:        The Go Programming Language
# source tree includes several copies of Mark.Twain-Tom.Sawyer.txt under Public Domain
License:        BSD and Public Domain
URL:            http://golang.org/
Source0:        https://github.com/golang/go/archive/%{go_commit}/golang-%{go_shortcommit}.tar.gz
# make possible to override default traceback level at build time by setting build tag rpm_crashtraceback
Source1:        fedora.go
Source2:        VERSION
Source3:        macros.golang

# The compiler is written in Go. Needs go(1.4+) compiler for build.
%if !%{golang_bootstrap}
BuildRequires:  gcc-go >= 5
%else
BuildRequires:  golang > 1.4
%endif
%if 0%{?rhel} > 6 || 0%{?fedora} > 0
BuildRequires:  hostname, procps-ng
%else
BuildRequires:  net-tools
%endif
# for tests
%if 0%{?rhel} < 8 || 0%{?fedora} > 0
BuildRequires:  glibc-static
%endif
BuildRequires:  pcre-devel, perl-interpreter

Provides:       go = %{version}-%{release}

# Bundled/Vendored provides generated by
# go list -f {{.ImportPath}} ./src/vendor/... | sed "s:_$PWD/src/vendor/::g;s:_:.:;s:.*:Provides\: bundled(golang(&)):" && go list -f {{.ImportPath}} ./src/cmd/vendor/... | sed "s:_$PWD/src/cmd/vendor/::g;s:_:.:;s:.*:Provides\: bundled(golang(&)):"
Provides: bundled(golang(golang.org/x/crypto/chacha20poly1305))
Provides: bundled(golang(golang.org/x/crypto/chacha20poly1305/internal/chacha20))
Provides: bundled(golang(golang.org/x/crypto/cryptobyte))
Provides: bundled(golang(golang.org/x/crypto/cryptobyte/asn1))
Provides: bundled(golang(golang.org/x/crypto/curve25519))
Provides: bundled(golang(golang.org/x/crypto/poly1305))
Provides: bundled(golang(golang.org/x/net/http2/hpack))
Provides: bundled(golang(golang.org/x/net/idna))
Provides: bundled(golang(golang.org/x/net/internal/nettest))
Provides: bundled(golang(golang.org/x/net/lex/httplex))
Provides: bundled(golang(golang.org/x/net/nettest))
Provides: bundled(golang(golang.org/x/net/proxy))
Provides: bundled(golang(golang.org/x/text/secure))
Provides: bundled(golang(golang.org/x/text/secure/bidirule))
Provides: bundled(golang(golang.org/x/text/transform))
Provides: bundled(golang(golang.org/x/text/unicode))
Provides: bundled(golang(golang.org/x/text/unicode/bidi))
Provides: bundled(golang(golang.org/x/text/unicode/norm))
Provides: bundled(golang(github.com/google/pprof))
Provides: bundled(golang(github.com/google/pprof/driver))
Provides: bundled(golang(github.com/google/pprof/internal/binutils))
Provides: bundled(golang(github.com/google/pprof/internal/driver))
Provides: bundled(golang(github.com/google/pprof/internal/elfexec))
Provides: bundled(golang(github.com/google/pprof/internal/graph))
Provides: bundled(golang(github.com/google/pprof/internal/measurement))
Provides: bundled(golang(github.com/google/pprof/internal/plugin))
Provides: bundled(golang(github.com/google/pprof/internal/proftest))
Provides: bundled(golang(github.com/google/pprof/internal/report))
Provides: bundled(golang(github.com/google/pprof/internal/symbolizer))
Provides: bundled(golang(github.com/google/pprof/internal/symbolz))
Provides: bundled(golang(github.com/google/pprof/profile))
Provides: bundled(golang(github.com/google/pprof/third.party/svg))
Provides: bundled(golang(github.com/ianlancetaylor/demangle))
Provides: bundled(golang(golang.org/x/arch/arm/armasm))
Provides: bundled(golang(golang.org/x/arch/arm64/arm64asm))
Provides: bundled(golang(golang.org/x/arch/ppc64/ppc64asm))
Provides: bundled(golang(golang.org/x/arch/x86/x86asm))

Requires:       %{name}-bin = %{version}-%{release}
Requires:       %{name}-src = %{version}-%{release}
%if 0%{?fedora} > 21
Requires:       go-srpm-macros
%endif

#Patch
Patch1:        0001-Don-t-use-the-bundled-tzdata-at-runtime-except-for-t.patch
Patch2:        0002-syscall-expose-IfInfomsg.X__ifi_pad-on-s390x.patch
Patch3:        0003-cmd-go-disable-Google-s-proxy-and-sumdb.patch

# Having documentation separate was broken
Obsoletes:      %{name}-docs < 1.1-4

# RPM can't handle symlink -> dir with subpackages, so merge back
Obsoletes:      %{name}-data < 1.1.1-4

# go1.4 deprecates a few packages
Obsoletes:      %{name}-vim < 1.4
Obsoletes:      emacs-%{name} < 1.4

# These are the only RHEL/Fedora architectures that we compile this package for
ExclusiveArch:  %{golang_arches}

%description
%{summary}.

%package       docs
Summary:       Golang compiler docs
Requires:      %{name} = %{version}-%{release}
BuildArch:     noarch
Obsoletes:     %{name}-docs < 1.1-4

%description   docs
%{summary}.

%package       misc
Summary:       Golang compiler miscellaneous sources
Requires:      %{name} = %{version}-%{release}
BuildArch:     noarch

%description   misc
%{summary}.

%package       tests
Summary:       Golang compiler tests for stdlib
Requires:      %{name} = %{version}-%{release}
BuildArch:     noarch

%description   tests
%{summary}.

%package        src
Summary:        Golang compiler source tree
BuildArch:      noarch
%description    src
%{summary}

%package        bin
Summary:        Golang core compiler tools
Requires:       go = %{version}-%{release}
# Pre-go1.5, all arches had to be bootstrapped individually, before usable, and
# env variables to compile for the target os-arch.
# Now the host compiler needs only the GOOS and GOARCH environment variables
# set to compile for the target os-arch.
Obsoletes:      %{name}-pkg-bin-linux-386 < 1.4.99
Obsoletes:      %{name}-pkg-bin-linux-amd64 < 1.4.99
Obsoletes:      %{name}-pkg-bin-linux-arm < 1.4.99
Obsoletes:      %{name}-pkg-linux-386 < 1.4.99
Obsoletes:      %{name}-pkg-linux-amd64 < 1.4.99
Obsoletes:      %{name}-pkg-linux-arm < 1.4.99
Obsoletes:      %{name}-pkg-darwin-386 < 1.4.99
Obsoletes:      %{name}-pkg-darwin-amd64 < 1.4.99
Obsoletes:      %{name}-pkg-windows-386 < 1.4.99
Obsoletes:      %{name}-pkg-windows-amd64 < 1.4.99
Obsoletes:      %{name}-pkg-plan9-386 < 1.4.99
Obsoletes:      %{name}-pkg-plan9-amd64 < 1.4.99
Obsoletes:      %{name}-pkg-freebsd-386 < 1.4.99
Obsoletes:      %{name}-pkg-freebsd-amd64 < 1.4.99
Obsoletes:      %{name}-pkg-freebsd-arm < 1.4.99
Obsoletes:      %{name}-pkg-netbsd-386 < 1.4.99
Obsoletes:      %{name}-pkg-netbsd-amd64 < 1.4.99
Obsoletes:      %{name}-pkg-netbsd-arm < 1.4.99
Obsoletes:      %{name}-pkg-openbsd-386 < 1.4.99
Obsoletes:      %{name}-pkg-openbsd-amd64 < 1.4.99

Obsoletes:      golang-vet < 0-12.1
Obsoletes:      golang-cover < 0-12.1

Requires(post): %{_sbindir}/update-alternatives
Requires(postun): %{_sbindir}/update-alternatives

# We strip the meta dependency, but go does require glibc.
# This is an odd issue, still looking for a better fix.
Requires:       glibc
Requires:       gcc
Requires:       git, subversion, mercurial
%description    bin
%{summary}

# Workaround old RPM bug of symlink-replaced-with-dir failure
%pretrans -p <lua>
for _,d in pairs({"api", "doc", "include", "lib", "src"}) do
  path = "%{goroot}/" .. d
  if posix.stat(path, "type") == "link" then
    os.remove(path)
    posix.mkdir(path)
  end
end

%if %{shared}
%package        shared
Summary:        Golang shared object libraries

%description    shared
%{summary}.
%endif

%if %{race}
%package        race
Summary:        Golang std library with -race enabled

Requires:       %{name} = %{version}-%{release}

%description    race
%{summary}
%endif

%prep
%setup -q -n go-%{go_commit}

#ApplyPatch
%patch1 -p1
%patch2 -p1
%patch3 -p1

cp %{SOURCE1} ./src/runtime/
cp %{SOURCE2} .

%build
# print out system information
uname -a
cat /proc/cpuinfo
cat /proc/meminfo

# bootstrap compiler GOROOT
%if !%{golang_bootstrap}
export GOROOT_BOOTSTRAP=/
%else
export GOROOT_BOOTSTRAP=%{goroot}
%endif

# set up final install location
export GOROOT_FINAL=%{goroot}

export GOHOSTOS=linux
export GOHOSTARCH=%{gohostarch}

pushd src
# use our gcc options for this build, but store gcc as default for compiler
export CFLAGS="$RPM_OPT_FLAGS"
export LDFLAGS="$RPM_LD_FLAGS"
export CC="gcc"
export CC_FOR_TARGET="gcc"
export GOOS=linux
export GOARCH=%{gohostarch}
%if !%{external_linker}
export GO_LDFLAGS="-linkmode internal"
%endif
%if !%{cgo_enabled}
export CGO_ENABLED=0
%endif
./make.bash --no-clean -v
popd

# build shared std lib
%if %{shared}
GOROOT=$(pwd) PATH=$(pwd)/bin:$PATH go install -buildmode=shared -v -x std
%endif

%if %{race}
GOROOT=$(pwd) PATH=$(pwd)/bin:$PATH go install -race -v -x std
%endif

%install
rm -rf $RPM_BUILD_ROOT
# remove GC build cache
rm -rf pkg/obj/go-build/*

# create the top level directories
mkdir -p $RPM_BUILD_ROOT%{_bindir}
mkdir -p $RPM_BUILD_ROOT%{goroot}

# install everything into libdir (until symlink problems are fixed)
# https://code.google.com/p/go/issues/detail?id=5830
cp -apv api bin doc favicon.ico lib pkg robots.txt src misc test VERSION \
   $RPM_BUILD_ROOT%{goroot}

# bz1099206
find $RPM_BUILD_ROOT%{goroot}/src -exec touch -r $RPM_BUILD_ROOT%{goroot}/VERSION "{}" \;
# and level out all the built archives
touch $RPM_BUILD_ROOT%{goroot}/pkg
find $RPM_BUILD_ROOT%{goroot}/pkg -exec touch -r $RPM_BUILD_ROOT%{goroot}/pkg "{}" \;
# generate the spec file ownership of this source tree and packages
cwd=$(pwd)
src_list=$cwd/go-src.list
pkg_list=$cwd/go-pkg.list
shared_list=$cwd/go-shared.list
race_list=$cwd/go-race.list
misc_list=$cwd/go-misc.list
docs_list=$cwd/go-docs.list
tests_list=$cwd/go-tests.list
rm -f $src_list $pkg_list $docs_list $misc_list $tests_list $shared_list $race_list
touch $src_list $pkg_list $docs_list $misc_list $tests_list $shared_list $race_list
pushd $RPM_BUILD_ROOT%{goroot}
    find src/ -type d -a \( ! -name testdata -a ! -ipath '*/testdata/*' \) -printf '%%%dir %{goroot}/%p\n' >> $src_list
    find src/ ! -type d -a \( ! -ipath '*/testdata/*' -a ! -name '*_test.go' \) -printf '%{goroot}/%p\n' >> $src_list

    find bin/ pkg/ -type d -a ! -path '*_dynlink/*' -a ! -path '*_race/*' -printf '%%%dir %{goroot}/%p\n' >> $pkg_list
    find bin/ pkg/ ! -type d -a ! -path '*_dynlink/*' -a ! -path '*_race/*' -printf '%{goroot}/%p\n' >> $pkg_list

    find doc/ -type d -printf '%%%dir %{goroot}/%p\n' >> $docs_list
    find doc/ ! -type d -printf '%{goroot}/%p\n' >> $docs_list

    find misc/ -type d -printf '%%%dir %{goroot}/%p\n' >> $misc_list
    find misc/ ! -type d -printf '%{goroot}/%p\n' >> $misc_list

%if %{shared}
    mkdir -p %{buildroot}/%{_libdir}/
    mkdir -p %{buildroot}/%{golibdir}/
    for file in $(find .  -iname "*.so" ); do
        chmod 755 $file
        mv  $file %{buildroot}/%{golibdir}
        pushd $(dirname $file)
        ln -fs %{golibdir}/$(basename $file) $(basename $file)
        popd
        echo "%%{goroot}/$file" >> $shared_list
        echo "%%{golibdir}/$(basename $file)" >> $shared_list
    done
    
	find pkg/*_dynlink/ -type d -printf '%%%dir %{goroot}/%p\n' >> $shared_list
	find pkg/*_dynlink/ ! -type d -printf '%{goroot}/%p\n' >> $shared_list
%endif

%if %{race}

    find pkg/*_race/ -type d -printf '%%%dir %{goroot}/%p\n' >> $race_list
    find pkg/*_race/ ! -type d -printf '%{goroot}/%p\n' >> $race_list

%endif

    find test/ -type d -printf '%%%dir %{goroot}/%p\n' >> $tests_list
    find test/ ! -type d -printf '%{goroot}/%p\n' >> $tests_list
    find src/ -type d -a \( -name testdata -o -ipath '*/testdata/*' \) -printf '%%%dir %{goroot}/%p\n' >> $tests_list
    find src/ ! -type d -a \( -ipath '*/testdata/*' -o -name '*_test.go' \) -printf '%{goroot}/%p\n' >> $tests_list
    # this is only the zoneinfo.zip
    find lib/ -type d -printf '%%%dir %{goroot}/%p\n' >> $tests_list
    find lib/ ! -type d -printf '%{goroot}/%p\n' >> $tests_list
popd

# remove the doc Makefile
rm -rfv $RPM_BUILD_ROOT%{goroot}/doc/Makefile

# put binaries to bindir, linked to the arch we're building,
# leave the arch independent pieces in {goroot}
mkdir -p $RPM_BUILD_ROOT%{goroot}/bin/linux_%{gohostarch}
ln -sf %{goroot}/bin/go $RPM_BUILD_ROOT%{goroot}/bin/linux_%{gohostarch}/go
ln -sf %{goroot}/bin/gofmt $RPM_BUILD_ROOT%{goroot}/bin/linux_%{gohostarch}/gofmt

# ensure these exist and are owned
mkdir -p $RPM_BUILD_ROOT%{gopath}/src/github.com
mkdir -p $RPM_BUILD_ROOT%{gopath}/src/bitbucket.org
mkdir -p $RPM_BUILD_ROOT%{gopath}/src/code.google.com/p
mkdir -p $RPM_BUILD_ROOT%{gopath}/src/golang.org/x

# make sure these files exist and point to alternatives
rm -f $RPM_BUILD_ROOT%{_bindir}/go
ln -sf /etc/alternatives/go $RPM_BUILD_ROOT%{_bindir}/go
rm -f $RPM_BUILD_ROOT%{_bindir}/gofmt
ln -sf /etc/alternatives/gofmt $RPM_BUILD_ROOT%{_bindir}/gofmt

#macros.golang
%if 0%{?rhel} > 5 || 0%{?fedora} < 21
%if 0%{?rhel} > 6 || 0%{?fedora} > 0
mkdir -p $RPM_BUILD_ROOT%{_rpmconfigdir}/macros.d
cp -av %{SOURCE2} $RPM_BUILD_ROOT%{_rpmconfigdir}/macros.d/macros.golang
%else
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/rpm
cp -av %{SOURCE2} $RPM_BUILD_ROOT%{_sysconfdir}/rpm/macros.golang
%endif
%endif

%check
export GOROOT=$(pwd -P)
export PATH="$GOROOT"/bin:"$PATH"
cd src

export CC="gcc"
export CFLAGS="$RPM_OPT_FLAGS"
export LDFLAGS="$RPM_LD_FLAGS"
%if !%{external_linker}
export GO_LDFLAGS="-linkmode internal"
%endif
%if !%{cgo_enabled} || !%{external_linker}
export CGO_ENABLED=0
%endif

# make sure to not timeout
export GO_TEST_TIMEOUT_SCALE=2
# export GO_TEST_SHORT=false

%if %{fail_on_tests}
./run.bash --no-rebuild -v -v -v -k
%else
./run.bash --no-rebuild -v -v -v -k || :
%endif
cd ..


%post bin
%{_sbindir}/update-alternatives --install %{_bindir}/go \
    go %{goroot}/bin/go 90 \
    --slave %{_bindir}/gofmt gofmt %{goroot}/bin/gofmt

%preun bin
if [ $1 = 0 ]; then
    %{_sbindir}/update-alternatives --remove go %{goroot}/bin/go
fi


%files
%doc AUTHORS CONTRIBUTORS LICENSE PATENTS
# VERSION has to be present in the GOROOT, for `go install std` to work
%doc %{goroot}/VERSION
%dir %{goroot}/doc
%doc %{goroot}/doc/*

# go files
%dir %{goroot}
%exclude %{goroot}/bin/
%exclude %{goroot}/pkg/
%exclude %{goroot}/src/
%exclude %{goroot}/doc/
%exclude %{goroot}/misc/
%exclude %{goroot}/test/
%{goroot}/*
%if 0%{?rhel} > 5 || 0%{?fedora} < 21
%if 0%{?rhel} > 6 || 0%{?fedora} > 0
%{_rpmconfigdir}/macros.d/macros.golang
%else
%{_sysconfdir}/rpm/macros.golang
%endif
%endif

# ensure directory ownership, so they are cleaned up if empty
%dir %{gopath}
%dir %{gopath}/src
%dir %{gopath}/src/github.com/
%dir %{gopath}/src/bitbucket.org/
%dir %{gopath}/src/code.google.com/
%dir %{gopath}/src/code.google.com/p/
%dir %{gopath}/src/golang.org
%dir %{gopath}/src/golang.org/x


%files -f go-src.list src

%files -f go-docs.list docs

%files -f go-misc.list misc

%files -f go-tests.list tests

%files -f go-pkg.list bin
%{_bindir}/go
%{_bindir}/gofmt

%if %{shared}
%files -f go-shared.list shared
%endif

%if %{race}
%files -f go-race.list race
%endif

%changelog
* Wed Apr 15 2020 Jakub Čajka <jcajka@fedoraproject.org> - 1.15-0.14gitc79c5e1
- Rebase to c79c5e1aa427eceb585f839a81d02c5390457a9c

* Thu Apr 09 2020 Jakub Čajka <jcajka@fedoraproject.org> - 1.15-0.13git98b6c6a
- Rebase to 98b6c6aca6fd4185f97dc40137707f4d8df8aa7c

* Tue Apr 07 2020 Jakub Čajka <jcajka@fedoraproject.org> - 1.15-0.12git74d6de0
- Rebase to 74d6de03fd7db2c6faa7794620a9bcf0c4f018f2

* Wed Apr 01 2020 Jakub Čajka <jcajka@fedoraproject.org> - 1.15-0.11git8e6a8d9
- Rebase to 8e6a8d9e282a6f9aeab5635c75c223129f5ab61f

* Wed Mar 18 2020 Jakub Čajka <jcajka@fedoraproject.org> - 1.15-0.10git6412750
- Rebase to 6412750f32224f6820f781d09b2092c5c358dddc

* Thu Mar 12 2020 Jakub Čajka <jcajka@fedoraproject.org> - 1.15-0.9git65bd076
- Rebase to 65bd07611c95d66c60eca57932714e6bd0059c54

* Wed Mar 04 2020 Jakub Čajka <jcajka@fedoraproject.org> - 1.15-0.8gitcd9fd64
- Rebase to cd9fd640db419ec81026945eb4f22bfe5ff5a27f

* Wed Feb 26 2020 Jakub Čajka <jcajka@fedoraproject.org> - 1.15-0.7gitcb74dcc
- Rebase to cb74dcc172de2779a2f65ea830f687156c98ad50

* Thu Feb 06 2020 Jakub Čajka <jcajka@fedoraproject.org> - 1.15-0.6gitee3a371
- Rebase to ee3a3717aa16dabede5dc0385b05423e8fbce985

* Mon Feb 03 2020 Jakub Čajka <jcajka@fedoraproject.org> - 1.15-0.5git753d56d
- Rebase to 753d56d3642eb83848aa39e65982a9fc77e722d7

* Fri Jan 31 2020 Jakub Čajka <jcajka@fedoraproject.org> - 1.15-0.4gitb7689f5
- Rebase to b7689f5aa38b41c8fbd75d64aa463b898c81fca5

* Sun Jan 26 2020 Jakub Čajka <jcajka@fedoraproject.org> - 1.15-0.3git73d2137
- Rebase to 73d213708e3186b48d5147b8eb939fdfd51f1f8d

* Tue Jan 21 2020 Jakub Čajka <jcajka@fedoraproject.org> - 1.15-0.2git71239b4
- Rebase to 71239b4f491698397149868c88d2c851de2cd49b

* Thu Jan 02 2020 Jakub Čajka <jcajka@fedoraproject.org> - 1.15-0.1gitbbd25d2
- Rebase to bbd25d26c0a86660fb3968137f16e74837b7a9c6

* Fri Dec 06 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.14-0.25git0915a19
- Rebase to 0915a19a115ba6bd2a5a95178bfaa076041d270b

* Mon Dec 02 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.14-0.24git8054b13
- Rebase to 8054b13536fc71d6f8867f90d7614de4064191ba

* Thu Nov 28 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.14-0.23git8a5af79
- Rebase to 8a5af7910a9b157c02736c3e0998a587bb8511c1

* Tue Nov 26 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.14-0.22git87805c9
- Rebase to 87805c92fd57d1535d0e497dd245ef783007b59d

* Fri Nov 22 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.14-0.21git95be9b7
- Rebase to 95be9b7559e5df1b2cb6b18b517f4f20de5b99a4

* Tue Nov 19 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.14-0.20git8cf5293
- Rebase to 8cf5293caa7071601fa90358abdd20a0b787e178

* Mon Nov 18 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.14-0.19git0ac8739
- Rebase to 0ac8739ad5394c3fe0420cf53232954fefb2418f

* Thu Nov 14 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.14-0.18git3f21c23
- Rebase to 3f21c2381d9b0f0977f388cc89104f557a7d2c88

* Wed Nov 06 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.14-0.17git0c5d545
- Rebase to 0c5d545ccdd01403d6ce865fb03774a6aff6032c

* Thu Oct 31 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.14-0.16gitd5caea7
- Rebase to d5caea771e917e13c4d05a6d7c5a009bf719d299

* Tue Oct 29 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.14-0.15git7067aa1
- Rebase to 7067aa1c106d000e99b62e4804118c7bceeed680

* Mon Oct 14 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.14-0.14gitc721994
- Rebase to c72199482f1ab55d824c5a49908c904d3617d170

* Wed Oct 09 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.14-0.13gita38a917
- Rebase to a38a917aee626a9b9d5ce2b93964f586bf759ea0

* Sat Oct 05 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.14-0.12gitb106105
- Rebase to b106105e52003627308189a0c455206506fcd925

* Thu Sep 12 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.14-0.11git48e482e
- Rebase to 48e482ef0c23032affce7998e985dee6fcda14bc

* Fri Aug 30 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.14-0.10git8c5de66
- Rebase to 8c5de667d3b1349a3058e4c57b01f0309502a118

* Mon Aug 26 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.14-0.9git78f6856
- Rebase to 78f6856ddf855a457bd33af27089cb3f6e1b2a2d

* Wed Aug 07 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.14-0.8git0ca4f6b
- Rebase to 0ca4f6be35d2abf54128b57c3aa1a1fcbd5adfe3

* Mon Aug 05 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.14-0.7git09c9d3a
- Rebase to 09c9d3a58a4aa1531ac516754f65c31aa8418d3f

* Thu Aug 01 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.14-0.6git8a317eb
- Rebase to 8a317ebc0f50339628c003bf06107cd865406dd4

* Mon Jul 15 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.14-0.5git89d300b
- Rebase to 89d300b821551c9955414caf3066ae602813f6ea

* Thu Jul 11 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.14-0.4git80cca23
- Rebase to 80cca23b59fe75ba588f7ddee7adb48a6afe2eb7

* Mon Jul 08 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.14-0.3git13327f2
- Rebase to 13327f219e5bb0f050eb41f25f9dd07ec3d56f32

* Wed Jul 03 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.14-0.2gite2fdce9
- Rebase to e2fdce9f16fa70af061f3b9cccdcecb4d795d484

* Fri Jun 28 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.14-0.1git67f181b
- Rebase to 67f181bfd84dfd5942fe9a29d8a20c9ce5eb2fea

* Wed Jun 26 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.13-0.32git9bf6278
- Rebase to 9bf62783d2fc3804fd31f68092e779ef52f26cf9

* Mon Jun 24 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.13-0.31gitc290cb6
- Rebase to c290cb6338fe9ce7d8ade3adbb4acd0f0e6172e4

* Thu Jun 20 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.13-0.30git71a6a44
- Rebase to 71a6a44428feb844b9dd3c4c8e16be8dee2fd8fa

* Mon Jun 17 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.13-0.29git7a4d023
- Rebase to 7a4d02387fa16cd2a88c30357346e5cf0ae282b1

* Thu Jun 13 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.13-0.28gitf83c44e
- Rebase to f83c44e031ebf1c85d4179cf7174fe89162d654a

* Wed Jun 12 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.13-0.27gitf2a4c13
- Rebase to f2a4c139c1e0cff35f89e4b5a531d5dedc5ed8e0

* Mon Jun 10 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.13-0.26git323212b
- Rebase to 323212b9e6edd55e99d973d00d2132995762c858

* Wed Jun 05 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.13-0.25git5f50914
- Rebase to 5f509148b13f196b12109d03809691cd1ed40284

* Fri May 31 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.13-0.24gitd53f380
- Rebase to d53f380e620c59cb3f30736584879c3c104ee488

* Tue May 28 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.13-0.23git0f897f9
- Rebase to 0f897f916aa6734bb8d089400ea996ee461ae41f

* Mon May 27 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.13-0.22gitd97bd5d
- Rebase to d97bd5d07ac4e7b342053b335428ff9c97212f9f

* Thu May 16 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.13-0.21gitfba6066
- Rebase to fba60669751a5362c43e3bdee8455bed3fa275b2

* Tue May 07 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.13-0.20git3e7e254
- Rebase to 3e7e2546fc77a80002afcd8ed890b3fe3af48972

* Mon May 06 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.13-0.19gitb41eee4
- Rebase to b41eee4c8a2fe692c1d9fb46972b9047b5dc02b7

* Thu May 02 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.13-0.18git74b3c50
- Rebase to 74b3c50eeb5d7c15dbf41524f6fa42d6d29e4cd6

* Tue Apr 30 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.13-0.17gitc2d9eea
- Rebase to c2d9eea1f1d5bc4c49e3a97384ffcb40b7dd52bf

* Thu Apr 25 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.13-0.16git44343c7
- Rebase to 44343c777ca8c02262d1d381a2cc24866b3c5414

* Tue Apr 23 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.13-0.15git7e08c7f
- Rebase to 7e08c7f43da876bc451b774808e323215a193abd

* Mon Apr 15 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.13-0.14git0bd101c
- Rebase to 0bd101cecc5458a8463b8d672bf1745c3cbb7c02

* Wed Apr 10 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.13-0.13git9a0a150
- Rebase to 9a0a150c9f50f920f35cc4d50ac3005503f44f2d

* Thu Apr 04 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.13-0.12git964fe4b
- Rebase to 964fe4b80ff7a9e5490f11de0e216ae34a019ebc

* Fri Mar 29 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.13-0.11gitddef157
- Rebase to ddef157813686870e26c3c2c83bd5af6bef71a61

* Tue Mar 05 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.13-0.10git95d4e61
- Rebase to 95d4e6158b4199e1eee957e2c8c934d2cb86c35e

* Thu Feb 28 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.13-0.9git61170f8
- Rebase to 61170f85e62f1326d42c4dbd8aa17ab4a1305a87

* Tue Feb 05 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.13-0.8git20c110e
- Rebase to 20c110eb2aacd9023bf7340252f14c83cba7abba

* Wed Jan 23 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.13-0.7git1fb5961
- Rebase to 1fb596143cd47145c8cee0c1c5ed5e871feeb2b1

* Mon Jan 21 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.13-0.6git8e50e48
- Rebase to 8e50e48f4ddd434b848240837a02a487d502b3ee

* Fri Jan 18 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.13-0.5gitc077c74
- Rebase to c077c74312563aad8117fe9f40fa85e1b5c87ac2

* Mon Jan 14 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.13-0.4git4e8aaf6
- Rebase to 4e8aaf6b22557a485cd3af874bf5be2722b07835

* Wed Jan 09 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.13-0.3git99ea99e
- Rebase to 99ea99ec4ca727ec3408521b07a6eb6a6bd3b829

* Tue Jan 08 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.13-0.2gita1d5e8a
- Rebase to a1d5e8adfa4d2f1043f4617fe20994ddbb7cc25c

* Wed Jan 02 2019 Jakub Čajka <jcajka@fedoraproject.org> - 1.13-0.1gitad16449
- Rebase to ad1644943ba691740c3bec29280f350f9d81c1b1

* Thu Dec 06 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.61git9e0ec5e
- Rebase to 9e0ec5ef5945696e90d7749d3569471c6f8b68c5

* Tue Dec 04 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.60gitffac3d5
- Rebase to ffac3d5a88352d4f6e8e47b9a2990352960eb5ca

* Fri Nov 30 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.59git2140975
- Rebase to 2140975ebde164ea1eaa70fc72775c03567f2bc9

* Thu Nov 29 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.58git2b58ca6
- Rebase to 2b58ca6e3de3d93817a4e6cc55378015eb3c2040

* Tue Nov 27 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.57git22dbc96
- Rebase to 22dbc96d8a004bb78a0efd329d0f48b6f0a8b9e5

* Mon Nov 26 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.56gitbb3b24b
- Rebase to bb3b24bffc4f50c64504c1c5f899aad0281a449a

* Fri Nov 23 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.55git649b893
- Rebase to 649b89377e91ad6dbe710784f9e662082d31a1ff

* Thu Nov 22 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.54git6d5caf3
- Rebase to 6d5caf38e37bf9aeba3291f1f0b0081f934b1187

* Mon Nov 19 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.53git0b9004f
- Rebase to 0b9004f1c08ae8c07454f5fb33b9c3848e07c932

* Thu Nov 15 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.52git7a6ccec
- Rebase to 7a6ccece877232fc58872c85fdf0718629b83d91

* Wed Nov 14 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.51git6d620fc
- Rebase to 6d620fc42ec2ae61cfedcd37d24afd8cb7654164

* Tue Nov 13 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.50gitde50ea3
- Rebase to de50ea3cd848f187766825402f8d6c8109536443

* Wed Nov 07 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.49gitac277d9
- Rebase to ac277d9234a89070a80dcbd03ef580566480fe42

* Tue Nov 06 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.48git510eea2
- Rebase to 510eea2dfcabbc8916c7c59aa37046269ad29497

* Mon Nov 05 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.47gitefd2292
- Rebase to efd229238aceefdee6a00ea28b61c924c2b5f1a5

* Sun Nov 04 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.46git6fe8ee7
- Rebase to 6fe8ee78e9b4870ebc1de2b5cfd6170a78a56c00

* Sat Nov 03 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.45git441cb98
- Rebase to 441cb988b4c63f4232edd7930758eb0e8cc8599b

* Fri Nov 02 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.44git5cc8089
- Rebase to 5cc80899486027db5f0de00870f1e022e1cfb9c5

* Wed Oct 31 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.43git5cc8089
- Rebase to 5cc80899486027db5f0de00870f1e022e1cfb9c5

* Mon Oct 29 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.42git37afd3e
- Rebase to 37afd3e31100a06229da61549abf5210a1dae8d0

* Thu Oct 25 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.41git41d6315
- Rebase to 41d6315e34f677c7102c73253819b12cf6e3e209

* Mon Oct 22 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.40git3bf9b77
- Rebase to 3bf9b77c0c8f123728fcfc802599232e9bd95476

* Thu Oct 18 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.39git8ccafb1
- Rebase to 8ccafb1ac732ab7994acb3c40786a0b943974554

* Mon Oct 15 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.38git9322b53
- Rebase to 9322b53396dc8aeb8bdfa825beb4d89f33216d93

* Tue Oct 09 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.37gitffc7bc5
- Rebase to ffc7bc55f351976c9bb1e04aeba75397d40cbb53

* Mon Oct 08 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.36git7c3b324
- Rebase to 7c3b324d265905eec137d92e3a0a9041cad3679d

* Sat Oct 06 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.35git8aee193
- Rebase to 8aee193fb8b61d474a7e3e6d43625f4e746c5b65

* Mon Oct 01 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.34git0b994a9
- Rebase to 0b994a9037b8972fd1cec8a170cea58cb2f93232

* Thu Sep 27 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.33git4ba4c5a
- Rebase to 4ba4c5ae795f30f167faef7c15dba3e32afc53d0

* Mon Sep 24 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.32gitce53683
- Rebase to ce536837d8e53f1bf0c7ef450d4580d19f7d6f52

* Fri Sep 21 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.31gitce58a39
- Rebase to ce58a39fca067a19c505220c0c907ccf32793427

* Thu Sep 20 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.30git9a033bf
- Rebase to 9a033bf9d3f5f7485d82836ec95e51a3fa74a926

* Tue Sep 18 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.29git0a87205
- Rebase to 0a8720580983c3a39c6c46fe08a2136a04bc118f

* Mon Sep 17 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.28git930ce09
- Rebase to 930ce09ca3a1ab5f886c2327fc143b9ae075807b

* Tue Sep 11 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.27git0f72e79
- Rebase to 0f72e79856d246af85c449f9e5a357ba751cd234

* Wed Sep 05 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.26gitf94de9c
- Rebase to f94de9c9fbed2a8d52a84b565c54da6efb015c4d

* Mon Sep 03 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.25gitb794ca6
- Rebase to b794ca64d29f3e584cbdf49bde7141d3c12dd2ab

* Fri Aug 31 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.24git8a2b5f1
- Rebase to 8a2b5f1f39152e45e6cfe6264612f00891d0327e

* Thu Aug 30 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.23gitbfaffb4
- Rebase to bfaffb4e23b956caf6b546c49bd1f28c358d9e2d

* Tue Aug 28 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.22git76c4587
- Rebase to 76c45877c9e72ccc84db787dc08299e0182e0efb

* Mon Aug 27 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.21git42cc4ca
- Rebase to 42cc4ca30a7729a4c6d1bb0bbbc3e4a736ef91c8

* Fri Aug 24 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.20git4363c98
- Rebase to 4363c98f62e9e315ed20b12d2ce47021fd2bf7bc

* Thu Aug 23 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.19gitc5d38b8
- Rebase to c5d38b896df504e3354d7a27f7ad86fa9661ce6b

* Wed Aug 22 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.18gitf4e4ec2
- Rebase to f4e4ec2cd09c2f9d821f3cb6f47edd7c41a90b25

* Mon Aug 20 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.17git88aa208
- Rebase to 88aa208024f04845381a86f2d5679d2e520b1ff6

* Wed Aug 15 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.16gitc882f4b
- Rebase to c882f4b6b13d4d38d354bec4614d4402031ec1b1

* Wed Aug 15 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.15git81555cb
- Rebase to 81555cb4f3521b53f9de4ce15f64b77cc9df61b9

* Thu Aug 09 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.14gitf2131f6
- Rebase to f2131f6e0c6ca016143fc402d9d01f6a730f97cd

* Mon Aug 06 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.13git5a720d2
- Rebase to 5a720d229d5ebc2f8b599aa54a3d807a1d54365f

* Fri Aug 03 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.12git4cc09cd
- Rebase to 4cc09cd5320a2bea4f27a1db59970d4b715f6522

* Fri Jul 27 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.11gitbd98a81
- Rebase to bd98a81dc27a740f4c4192cc8799884da62c4bad

* Fri Jul 27 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.10gitbd98a81
- Rebase to bd98a81dc27a740f4c4192cc8799884da62c4bad

* Wed Jul 25 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.9git5f5402b
- Rebase to 5f5402b72313463a25c1bcacd559254834690d7e

* Tue Jul 24 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.8git08ab820
- Rebase to 08ab820437229f68fe5f7dad1c9b4940c674e206

* Mon Jul 23 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.7git48c7973
- Rebase to 48c79734ffc69c7137d5944eb6403b47075cfb77

* Fri Jul 20 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.6git4f1f503
- Rebase to 4f1f503373cda7160392be94e3849b0c9b9ebbda

* Wed Jul 18 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.5gita371bc2
- Rebase to a371bc2dfdf1fe4166c83be1177fbecb03d8da53

* Mon Jul 16 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.4git22e17d0
- Rebase to 22e17d0ac7db5321a0f6e073bd0afb949f44dd70

* Fri Jul 13 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.3git8a33045
- Rebase to 8a330454dc1502091dba2c890f5f6d0c095034de

* Mon Jul 09 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.2gitb56e247
- Rebase to b56e24782f81002fabe06bdf65a735ac7e2b6e1f

* Tue Jul 03 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.12-0.1git66b2401
- Rebase to 66b240153fd69d754ed9b544ebe116e593be1390

* Wed Jun 20 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.11-0.26git0c9be48
- Rebase to 0c9be48a90bfafac68cde05c4d7db8eee17492f6

* Sat Jun 16 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.11-0.25gitcdffe9b
- Rebase to cdffe9b1e3dc54dd52a221e65e577f6c76ad39b8

* Fri Jun 15 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.11-0.24git4eb1c84
- Rebase to 4eb1c84752b8d3171be930abf4281080d639f634

* Thu Jun 14 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.11-0.23gitaf4d604
- Rebase to af4d60428f6dc5eab10b6de23235f61cceee8bc3

* Wed Jun 13 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.11-0.22gitf297d16
- Rebase to f297d165c9b6518151f50eb59cec9bd95794986b

* Tue Jun 12 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.11-0.21git9ef9765
- Rebase to 9ef9765c168c8561b98dc41c25eb8ae83abfcd7a

* Mon Jun 11 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.11-0.20git679690f
- Rebase to 679690f348a38591ccf180d9f699fc40a544e6af

* Fri Jun 08 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.11-0.19git29e5a81
- Rebase to 29e5a81e28c633aa8d1062ce9f3749e9a8f040da

* Thu Jun 07 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.11-0.18gite5f0c1f
- Rebase to e5f0c1f6c9dc382bdc6a0ec1a0d5e1fc6f833485

* Wed Jun 06 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.11-0.17git2ce295e
- Rebase to 2ce295e9542c104110a050bf809dd0a37e191eb7

* Fri Jun 01 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.11-0.16git063f97a
- Rebase to 063f97a6110079c2aaeb5f2c2a51d7f1bc7445ab

* Wed May 30 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.11-0.15gitf5cf72d
- Rebase to f5cf72d43ed1441d2e80654be5bde4b11f4cbcd1

* Tue May 29 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.11-0.14git5c36fdf
- Rebase to 5c36fdfd39e231e87b267fc718c9fd6a86f49b90

* Mon May 28 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.11-0.13git4fe688c
- Rebase to 4fe688c6a49e59e852f0bfebbb4cf71366987ce7

* Thu May 24 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.11-0.12git65c365b
- Rebase to 65c365bf0f4add682419ba8fe68db43a0cab0e83

* Wed May 23 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.11-0.11git4bb649f
- Rebase to 4bb649fba82412c292974a9f9255db1092d7faed

* Mon May 21 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.11-0.10gitcc09212
- Rebase to cc09212f59ee215cae5345dc1ffcd1ed81664e1b

* Thu May 03 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.11-0.9git78cb5d7
- Rebase to 78cb5d7a68f994978b1520baf724c8a7008a97c0

* Wed May 02 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.11-0.8git500d79c
- Rebase to 500d79c410f8e9ad762ba318a0a4b05d0d4d1751

* Wed Apr 25 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.11-0.7git74f9432
- Rebase to 74f9432beadb7179169e08b6c910dd533c62b7c8

* Tue Apr 24 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.11-0.6git665b9b3
- Rebase to 665b9b3476ad0a6dc4e578e42e6c63012e23aaa0

* Mon Apr 23 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.11-0.5gitd11df8b
- Rebase to d11df8baa8c18c7cf14e7286f55ae56f4439d1cd

* Sat Apr 21 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.11-0.4git0a129db
- Rebase to 0a129dbca6b76e919041d759e8d9a23fc075e6d5

* Thu Apr 19 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.11-0.3git206ed90
- Rebase to 206ed90eafdb1a6b4438298e580b25dbd23cfe44

* Mon Apr 16 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.11-0.2git93f95a3
- Rebase to 93f95a30a3c20774bca22e77ebbb5c1f3a8ce008

* Thu Apr 12 2018 Jakub Čajka <jcajka@fedoraproject.org> - 1.11-0.1git2d26a65
- Rebase to 2d26a65f8f1a6fcb0948803589061d99b94fa993

* Wed Apr 04 2018 Jakub Čajka <jcajka@redhat.com> - 1.10.1-1
- Rebase to 1.10.1
- Resolves: BZ#1562270

* Sat Mar 03 2018 Jakub Čajka <jcajka@redhat.com> - 1.10-2
- Fix CVE-2018-7187
- Resolves: BZ#1546386, BZ#1546388

* Wed Feb 21 2018 Jakub Čajka <jcajka@redhat.com> - 1.10-1
- Rebase to 1.10

* Thu Feb 08 2018 Jakub Čajka <jcajka@redhat.com> - 1.10-0.rc2.1
- Rebase to 1.10rc2
- Fix CVE-2018-6574
- Resolves: BZ#1543561, BZ#1543562

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.10-0.rc1.1.1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Fri Jan 26 2018 Jakub Čajka <jcajka@redhat.com> - 1.10-0.rc1.1
- Rebase to 1.10rc1

* Fri Jan 12 2018 Jakub Čajka <jcajka@redhat.com> - 1.10-0.beta2.1
- Rebase to 1.10beta2

* Mon Jan 08 2018 Jakub Čajka <jcajka@redhat.com> - 1.10-0.beta1.1
- Rebase to 1.10beta1
- Drop verbose patch as most of it is now implemented by bootstrap tool and is easily toggled by passing -v flag to make.bash

* Thu Oct 26 2017 Jakub Čajka <jcajka@redhat.com> - 1.9.2-1
- Rebase to 1.9.2
- execute correctly pie tests
- allow to ignore tests via bcond
- reduce size of golang package

* Fri Oct 06 2017 Jakub Čajka <jcajka@redhat.com> - 1.9.1-1
- fix CVE-2017-15041 and CVE-2017-15042

* Fri Sep 15 2017 Jakub Čajka <jcajka@redhat.com> - 1.9-1
- bump to the relased version

* Wed Aug 02 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.9-0.beta2.1.2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.9-0.beta2.1.1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Tue Jul 11 2017 Jakub Čajka <jcajka@redhat.com> - 1.9-0.beta2.1
- bump to beta2

* Thu May 25 2017 Jakub Čajka <jcajka@redhat.com> - 1.8.3-1
- bump to 1.8.3
- fix for CVE-2017-8932
- make possible to use 31bit OID in ASN1
- Resolves: BZ#1454978, BZ#1455191

* Fri Apr 21 2017 Jakub Čajka <jcajka@redhat.com> - 1.8.1-2
- fix uint64 constant codegen on s390x
- Resolves: BZ#1441078

* Tue Apr 11 2017 Jakub Čajka <jcajka@redhat.com> - 1.8.1-1
- bump to Go 1.8.1
- Resolves: BZ#1440345

* Fri Feb 24 2017 Jakub Čajka <jcajka@redhat.com> - 1.8-2
- avoid possibly stale packages due to chacha test file not being test file

* Fri Feb 17 2017 Jakub Čajka <jcajka@redhat.com> - 1.8-1
- bump to released version
- Resolves: BZ#1423637
- Related: BZ#1411242

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.8-0.rc3.2.1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Fri Jan 27 2017 Jakub Čajka <jcajka@redhat.com> - 1.8-0.rc3.2
- make possible to override default traceback level at build time
- add sub-package race containing std lib built with -race enabled
- Related: BZ#1411242

* Fri Jan 27 2017 Jakub Čajka <jcajka@redhat.com> - 1.8-0.rc3.1
- rebase to go1.8rc3
- Resolves: BZ#1411242

* Fri Jan 20 2017 Jakub Čajka <jcajka@redhat.com> - 1.7.4-2
- Resolves: BZ#1404679
- expose IfInfomsg.X__ifi_pad on s390x

* Fri Dec 02 2016 Jakub Čajka <jcajka@redhat.com> - 1.7.4-1
- Bump to 1.7.4
- Resolves: BZ#1400732

* Thu Nov 17 2016 Tom Callaway <spot@fedoraproject.org> - 1.7.3-2
- re-enable the NIST P-224 curve

* Thu Oct 20 2016 Jakub Čajka <jcajka@redhat.com> - 1.7.3-1
- Resolves: BZ#1387067 - golang-1.7.3 is available
- added fix for tests failing with latest tzdata

* Fri Sep 23 2016 Jakub Čajka <jcajka@redhat.com> - 1.7.1-2
- fix link failure due to relocation overflows on PPC64X

* Thu Sep 08 2016 Jakub Čajka <jcajka@redhat.com> - 1.7.1-1
- rebase to 1.7.1
- Resolves: BZ#1374103

* Tue Aug 23 2016 Jakub Čajka <jcajka@redhat.com> - 1.7-1
- update to released version
- related: BZ#1342090, BZ#1357394

* Mon Aug 08 2016 Jakub Čajka <jcajka@redhat.com> - 1.7-0.3.rc5
- Obsolete golang-vet and golang-cover from golang-googlecode-tools package
  vet/cover binaries are provided by golang-bin rpm (thanks to jchaloup)
- clean up exclusive arch after s390x boostrap
- resolves: #1268206

* Wed Aug 03 2016 Jakub Čajka <jcajka@redhat.com> - 1.7-0.2.rc5
- rebase to go1.7rc5
- Resolves: BZ#1342090

* Thu Jul 21 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.7-0.1.rc2
- https://fedoraproject.org/wiki/Changes/golang1.7

* Tue Jul 19 2016 Jakub Čajka <jcajka@redhat.com> - 1.7-0.0.rc2
- rebase to 1.7rc2
- added s390x build
- improved shared lib packaging
- Resolves: bz1357602 - CVE-2016-5386
- Resolves: bz1342090, bz1342090

* Tue Apr 26 2016 Jakub Čajka <jcajka@redhat.com> - 1.6.2-1
- rebase to 1.6.2
- Resolves: bz1329206 - golang-1.6.2.src is available

* Wed Apr 13 2016 Jakub Čajka <jcajka@redhat.com> - 1.6.1-1
- rebase to 1.6.1
- Resolves: bz1324344 - CVE-2016-3959
- Resolves: bz1324951 - prelink is gone, /etc/prelink.conf.d/* is no longer used
- Resolves: bz1326366 - wrong epoll_event struct for ppc64le/ppc64

* Mon Feb 22 2016 Jakub Čajka <jcajka@redhat.com> - 1.6-1
- Resolves: bz1304701 - rebase to go1.6 release
- Resolves: bz1304591 - fix possible stack miss-alignment in callCgoMmap

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.6-0.3.rc1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Fri Jan 29 2016 Jakub Čajka <jcajka@redhat.com> - 1.6-0.2.rc1
- disabled cgo and external linking on ppc64

* Thu Jan 28 2016 Jakub Čajka <jcajka@redhat.com> - 1.6-0.1.rc1
- Resolves bz1292640, rebase to pre-release 1.6
- bootstrap for PowerPC
- fix rpmlint errors/warning

* Thu Jan 14 2016 Jakub Čajka <jcajka@redhat.com> - 1.5.3-1
- rebase to 1.5.3
- resolves bz1293451, CVE-2015-8618
- apply timezone patch, avoid using bundled data
- print out rpm build system info

* Fri Dec 11 2015 Jakub Čajka <jcajka@redhat.com> - 1.5.2-2
- bz1290543 Accept x509 certs with negative serial

* Tue Dec 08 2015 Jakub Čajka <jcajka@redhat.com> - 1.5.2-1
- bz1288263 rebase to 1.5.2
- spec file clean up
- added build options
- scrubbed "Project Gutenberg License"

* Mon Oct 19 2015 Vincent Batts <vbatts@fedoraproject.org> - 1.5.1-1
- bz1271709 include patch from upstream fix

* Wed Sep 09 2015 Vincent Batts <vbatts@fedoraproject.org> - 1.5.1-0
- update to go1.5.1

* Fri Sep 04 2015 Vincent Batts <vbatts@fedoraproject.org> - 1.5-8
- bz1258166 remove srpm macros, for go-srpm-macros

* Thu Sep 03 2015 Vincent Batts <vbatts@fedoraproject.org> - 1.5-7
- bz1258166 remove srpm macros, for go-srpm-macros

* Thu Aug 27 2015 Vincent Batts <vbatts@fedoraproject.org> - 1.5-6
- starting a shared object subpackage. This will be x86_64 only until upstream supports more arches shared objects.

* Thu Aug 27 2015 Vincent Batts <vbatts@fedoraproject.org> - 1.5-5
- bz991759 gdb path fix

* Wed Aug 26 2015 Vincent Batts <vbatts@fedoraproject.org> - 1.5-4
- disable shared object until linux/386 is ironned out
- including the test/ directory for tests

* Tue Aug 25 2015 Vincent Batts <vbatts@fedoraproject.org> - 1.5-3
- bz1256910 only allow the golang zoneinfo.zip to be used in tests
- bz1166611 add golang.org/x directory
- bz1256525 include stdlib shared object. This will let other libraries and binaries
  build with `go build -buildmode=shared -linkshared ...` or similar.

* Sun Aug 23 2015 Peter Robinson <pbrobinson@fedoraproject.org> 1.5-2
- Enable aarch64
- Minor cleanups

* Thu Aug 20 2015 Vincent Batts <vbatts@fedoraproject.org> - 1.5-1
- updating to go1.5

* Thu Aug 06 2015 Vincent Batts <vbatts@fedoraproject.org> - 1.5-0.11.rc1
- fixing the sources reference

* Thu Aug 06 2015 Vincent Batts <vbatts@fedoraproject.org> - 1.5-0.10.rc1
- updating to go1.5rc1
- checks are back in place

* Tue Aug 04 2015 Vincent Batts <vbatts@fedoraproject.org> - 1.5-0.9.beta3
- pull in upstream archive/tar fix

* Thu Jul 30 2015 Vincent Batts <vbatts@fedoraproject.org> - 1.5-0.8.beta3
- updating to go1.5beta3

* Thu Jul 30 2015 Vincent Batts <vbatts@fedoraproject.org> - 1.5-0.7.beta2
- add the patch ..

* Thu Jul 30 2015 Vincent Batts <vbatts@fedoraproject.org> - 1.5-0.6.beta2
- increase ELFRESERVE (bz1248071)

* Tue Jul 28 2015 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.5-0.5.beta2
- correct package version and release tags as per naming guidelines

* Fri Jul 17 2015 Vincent Batts <vbatts@fedoraproject.org> - 1.4.99-4.1.5beta2
- adding test output, for visibility

* Fri Jul 10 2015 Vincent Batts <vbatts@fedoraproject.org> - 1.4.99-3.1.5beta2
- updating to go1.5beta2

* Fri Jul 10 2015 Vincent Batts <vbatts@fedoraproject.org> - 1.4.99-2.1.5beta1
- add checksum to sources and fixed one patch

* Fri Jul 10 2015 Vincent Batts <vbatts@fedoraproject.org> - 1.4.99-1.1.5beta1
- updating to go1.5beta1

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Wed Mar 18 2015 Vincent Batts <vbatts@fedoraproject.org> - 1.4.2-2
- obsoleting deprecated packages

* Wed Feb 18 2015 Vincent Batts <vbatts@fedoraproject.org> - 1.4.2-1
- updating to go1.4.2

* Fri Jan 16 2015 Vincent Batts <vbatts@fedoraproject.org> - 1.4.1-1
- updating to go1.4.1

* Fri Jan 02 2015 Vincent Batts <vbatts@fedoraproject.org> - 1.4-2
- doc organizing

* Thu Dec 11 2014 Vincent Batts <vbatts@fedoraproject.org> - 1.4-1
- update to go1.4 release

* Wed Dec 03 2014 Vincent Batts <vbatts@fedoraproject.org> - 1.3.99-3.1.4rc2
- update to go1.4rc2

* Mon Nov 17 2014 Vincent Batts <vbatts@fedoraproject.org> - 1.3.99-2.1.4rc1
- update to go1.4rc1

* Thu Oct 30 2014 Vincent Batts <vbatts@fedoraproject.org> - 1.3.99-1.1.4beta1
- update to go1.4beta1

* Thu Oct 30 2014 Vincent Batts <vbatts@fedoraproject.org> - 1.3.3-3
- macros will need to be in their own rpm

* Fri Oct 24 2014 Vincent Batts <vbatts@fedoraproject.org> - 1.3.3-2
- split out rpm macros (bz1156129)
- progress on gccgo accomodation

* Wed Oct 01 2014 Vincent Batts <vbatts@fedoraproject.org> - 1.3.3-1
- update to go1.3.3 (bz1146882)

* Mon Sep 29 2014 Vincent Batts <vbatts@fedoraproject.org> - 1.3.2-1
- update to go1.3.2 (bz1147324)

* Thu Sep 11 2014 Vincent Batts <vbatts@fedoraproject.org> - 1.3.1-3
- patching the tzinfo failure

* Sat Aug 16 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Wed Aug 13 2014 Vincent Batts <vbatts@fedoraproject.org> - 1.3.1-1
- update to go1.3.1

* Wed Aug 13 2014 Vincent Batts <vbatts@fedoraproject.org> - 1.3-11
- merged a line wrong

* Wed Aug 13 2014 Vincent Batts <vbatts@fedoraproject.org> - 1.3-10
- more work to get cgo.a timestamps to line up, due to build-env
- explicitly list all the files and directories for the source and packages trees
- touch all the built archives to be the same

* Mon Aug 11 2014 Vincent Batts <vbatts@fedoraproject.org> - 1.3-9
- make golang-src 'noarch' again, since that was not a fix, and takes up more space

* Mon Aug 11 2014 Vincent Batts <vbatts@fedoraproject.org> - 1.3-8
- update timestamps of source files during %%install bz1099206

* Fri Aug 08 2014 Vincent Batts <vbatts@fedoraproject.org> - 1.3-7
- update timestamps of source during %%install bz1099206

* Wed Aug 06 2014 Vincent Batts <vbatts@fedoraproject.org> - 1.3-6
- make the source subpackage arch'ed, instead of noarch

* Mon Jul 21 2014 Vincent Batts <vbatts@fedoraproject.org> - 1.3-5
- fix the writing of pax headers

* Tue Jul 15 2014 Vincent Batts <vbatts@fedoraproject.org> - 1.3-4
- fix the loading of gdb safe-path. bz981356

* Tue Jul 08 2014 Vincent Batts <vbatts@fedoraproject.org> - 1.3-3
- `go install std` requires gcc, to build cgo. bz1105901, bz1101508

* Mon Jul 07 2014 Vincent Batts <vbatts@fedoraproject.org> - 1.3-2
- archive/tar memory allocation improvements

* Thu Jun 19 2014 Vincent Batts <vbatts@fedoraproject.org> - 1.3-1
- update to go1.3

* Fri Jun 13 2014 Vincent Batts <vbatts@fedoraproject.org> - 1.3rc2-1
- update to go1.3rc2

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3rc1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Tue Jun 03 2014 Vincent Batts <vbatts@redhat.com> 1.3rc1-1
- update to go1.3rc1
- new arch file shuffling

* Wed May 21 2014 Vincent Batts <vbatts@redhat.com> 1.3beta2-1
- update to go1.3beta2
- no longer provides go-mode for xemacs (emacs only)

* Wed May 21 2014 Vincent Batts <vbatts@redhat.com> 1.2.2-7
- bz1099206 ghost files are not what is needed

* Tue May 20 2014 Vincent Batts <vbatts@redhat.com> 1.2.2-6
- bz1099206 more fixing. The packages %%post need golang-bin present first

* Tue May 20 2014 Vincent Batts <vbatts@redhat.com> 1.2.2-5
- bz1099206 more fixing. Let go fix its own timestamps and freshness

* Tue May 20 2014 Vincent Batts <vbatts@redhat.com> 1.2.2-4
- fix the existence and alternatives of `go` and `gofmt`

* Mon May 19 2014 Vincent Batts <vbatts@redhat.com> 1.2.2-3
- bz1099206 fix timestamp issue caused by koji builders

* Fri May 09 2014 Vincent Batts <vbatts@redhat.com> 1.2.2-2
- more arch file shuffling

* Fri May 09 2014 Vincent Batts <vbatts@redhat.com> 1.2.2-1
- update to go1.2.2

* Thu May 08 2014 Vincent Batts <vbatts@redhat.com> 1.2.1-8
- RHEL6 rpm macros can't %%exlude missing files

* Wed May 07 2014 Vincent Batts <vbatts@redhat.com> 1.2.1-7
- missed two arch-dependent src files

* Wed May 07 2014 Vincent Batts <vbatts@redhat.com> 1.2.1-6
- put generated arch-dependent src in their respective RPMs

* Fri Apr 11 2014 Vincent Batts <vbatts@redhat.com> 1.2.1-5
- skip test that is causing a SIGABRT on fc21 bz1086900

* Thu Apr 10 2014 Vincent Batts <vbatts@fedoraproject.org> 1.2.1-4
- fixing file and directory ownership bz1010713

* Wed Apr 09 2014 Vincent Batts <vbatts@fedoraproject.org> 1.2.1-3
- including more to macros (%%go_arches)
- set a standard goroot as /usr/lib/golang, regardless of arch
- include sub-packages for compiler toolchains, for all golang supported architectures

* Wed Mar 26 2014 Vincent Batts <vbatts@fedoraproject.org> 1.2.1-2
- provide a system rpm macros. Starting with gopath

* Tue Mar 04 2014 Adam Miller <maxamillion@fedoraproject.org> 1.2.1-1
- Update to latest upstream

* Thu Feb 20 2014 Adam Miller <maxamillion@fedoraproject.org> 1.2-7
- Remove  _BSD_SOURCE and _SVID_SOURCE, they are deprecated in recent
  versions of glibc and aren't needed

* Wed Feb 19 2014 Adam Miller <maxamillion@fedoraproject.org> 1.2-6
- pull in upstream archive/tar implementation that supports xattr for
  docker 0.8.1

* Tue Feb 18 2014 Vincent Batts <vbatts@redhat.com> 1.2-5
- provide 'go', so users can yum install 'go'

* Fri Jan 24 2014 Vincent Batts <vbatts@redhat.com> 1.2-4
- skip a flaky test that is sporadically failing on the build server

* Thu Jan 16 2014 Vincent Batts <vbatts@redhat.com> 1.2-3
- remove golang-godoc dependency. cyclic dependency on compiling godoc

* Wed Dec 18 2013 Vincent Batts <vbatts@redhat.com> - 1.2-2
- removing P224 ECC curve

* Mon Dec 2 2013 Vincent Batts <vbatts@fedoraproject.org> - 1.2-1
- Update to upstream 1.2 release
- remove the pax tar patches

* Tue Nov 26 2013 Vincent Batts <vbatts@redhat.com> - 1.1.2-8
- fix the rpmspec conditional for rhel and fedora

* Thu Nov 21 2013 Vincent Batts <vbatts@redhat.com> - 1.1.2-7
- patch tests for testing on rawhide
- let the same spec work for rhel and fedora

* Wed Nov 20 2013 Vincent Batts <vbatts@redhat.com> - 1.1.2-6
- don't symlink /usr/bin out to ../lib..., move the file
- seperate out godoc, to accomodate the go.tools godoc

* Fri Sep 20 2013 Adam Miller <maxamillion@fedoraproject.org> - 1.1.2-5
- Pull upstream patches for BZ#1010271
- Add glibc requirement that got dropped because of meta dep fix

* Fri Aug 30 2013 Adam Miller <maxamillion@fedoraproject.org> - 1.1.2-4
- fix the libc meta dependency (thanks to vbatts [at] redhat.com for the fix)

* Tue Aug 27 2013 Adam Miller <maxamillion@fedoraproject.org> - 1.1.2-3
- Revert incorrect merged changelog

* Tue Aug 27 2013 Adam Miller <maxamillion@fedoraproject.org> - 1.1.2-2
- This was reverted, just a placeholder changelog entry for bad merge

* Tue Aug 20 2013 Adam Miller <maxamillion@fedoraproject.org> - 1.1.2-1
- Update to latest upstream

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.1-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Wed Jul 17 2013 Petr Pisar <ppisar@redhat.com> - 1.1.1-6
- Perl 5.18 rebuild

* Wed Jul 10 2013 Adam Goode <adam@spicenitz.org> - 1.1.1-5
- Blacklist testdata files from prelink
- Again try to fix #973842

* Fri Jul  5 2013 Adam Goode <adam@spicenitz.org> - 1.1.1-4
- Move src to libdir for now (#973842) (upstream issue https://code.google.com/p/go/issues/detail?id=5830)
- Eliminate noarch data package to work around RPM bug (#975909)
- Try to add runtime-gdb.py to the gdb safe-path (#981356)

* Wed Jun 19 2013 Adam Goode <adam@spicenitz.org> - 1.1.1-3
- Use lua for pretrans (http://fedoraproject.org/wiki/Packaging:Guidelines#The_.25pretrans_scriptlet)

* Mon Jun 17 2013 Adam Goode <adam@spicenitz.org> - 1.1.1-2
- Hopefully really fix #973842
- Fix update from pre-1.1.1 (#974840)

* Thu Jun 13 2013 Adam Goode <adam@spicenitz.org> - 1.1.1-1
- Update to 1.1.1
- Fix basically useless package (#973842)

* Sat May 25 2013 Dan Horák <dan[at]danny.cz> - 1.1-3
- set ExclusiveArch

* Fri May 24 2013 Adam Goode <adam@spicenitz.org> - 1.1-2
- Fix noarch package discrepancies

* Fri May 24 2013 Adam Goode <adam@spicenitz.org> - 1.1-1
- Initial Fedora release.
- Update to 1.1

* Thu May  9 2013 Adam Goode <adam@spicenitz.org> - 1.1-0.3.rc3
- Update to rc3

* Thu Apr 11 2013 Adam Goode <adam@spicenitz.org> - 1.1-0.2.beta2
- Update to beta2

* Tue Apr  9 2013 Adam Goode <adam@spicenitz.org> - 1.1-0.1.beta1
- Initial packaging.
